@@ -10,12 +10,12 @@ use namespace::autoclean;
 use DBIx::Custom;
 
 #------------------------------------------------------------------------------
-# 继承 Firewall::DBI::Role 方法属性
+# 继承 Netstack::DBI::Role 方法属性
 #------------------------------------------------------------------------------
-with 'Firewall::DBI::Role';
+with 'Netstack::DBI::Role';
 
 #------------------------------------------------------------------------------
-# 定义 Firewall::DBI::Pg 方法属性
+# 定义 Netstack::DBI::Pg 方法属性
 #------------------------------------------------------------------------------
 has option => (
   is      => 'ro',
